# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/edge_v1/edge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/edge_v1/edge.proto\x12 stream.video.coordinator.edge_v1\x1a\x17validate/validate.proto\"\xaf\x01\n\x0b\x43redentials\x12\x46\n\x06server\x18\x01 \x01(\x0b\x32,.stream.video.coordinator.edge_v1.EdgeServerB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x16\n\x05token\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x0bice_servers\x18\x03 \x03(\x0b\x32+.stream.video.coordinator.edge_v1.ICEServer\"\xd4\x01\n\x13LatencyMeasurements\x12]\n\x0cmeasurements\x18\x01 \x03(\x0b\x32G.stream.video.coordinator.edge_v1.LatencyMeasurements.MeasurementsEntry\x1a^\n\x11MeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).stream.video.coordinator.edge_v1.Latency:\x02\x38\x01\"\'\n\x07Latency\x12\x1c\n\x14measurements_seconds\x18\x01 \x03(\x01\"(\n\x0b\x43oordinates\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0c\n\x04long\x18\x02 \x01(\x02\"\x7f\n\x04\x45\x64ge\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x0blatency_url\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x42\n\x0b\x63oordinates\x18\x03 \x01(\x0b\x32-.stream.video.coordinator.edge_v1.Coordinates\"=\n\tICEServer\x12\x0c\n\x04urls\x18\x01 \x03(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\",\n\nEdgeServer\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tedge_name\x18\x02 \x01(\tB1B\x06\x45\x64geV1P\x01Z\x07\x65\x64ge_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.edge_v1.edge_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006EdgeV1P\001Z\007edge_v1\252\002\033Stream.Video.v1.Coordinator'
  _CREDENTIALS.fields_by_name['server']._options = None
  _CREDENTIALS.fields_by_name['server']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREDENTIALS.fields_by_name['token']._options = None
  _CREDENTIALS.fields_by_name['token']._serialized_options = b'\372B\004r\002\020\001'
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._options = None
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._serialized_options = b'8\001'
  _EDGE.fields_by_name['name']._options = None
  _EDGE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _EDGE.fields_by_name['latency_url']._options = None
  _EDGE.fields_by_name['latency_url']._serialized_options = b'\372B\004r\002\020\001'
  _CREDENTIALS._serialized_start=100
  _CREDENTIALS._serialized_end=275
  _LATENCYMEASUREMENTS._serialized_start=278
  _LATENCYMEASUREMENTS._serialized_end=490
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._serialized_start=396
  _LATENCYMEASUREMENTS_MEASUREMENTSENTRY._serialized_end=490
  _LATENCY._serialized_start=492
  _LATENCY._serialized_end=531
  _COORDINATES._serialized_start=533
  _COORDINATES._serialized_end=573
  _EDGE._serialized_start=575
  _EDGE._serialized_end=702
  _ICESERVER._serialized_start=704
  _ICESERVER._serialized_end=765
  _EDGESERVER._serialized_start=767
  _EDGESERVER._serialized_end=811
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/models/models.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvideo/sfu/models/models.proto\x12\x17stream.video.sfu.models\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"G\n\tCallState\x12:\n\x0cparticipants\x18\x01 \x03(\x0b\x32$.stream.video.sfu.models.Participant\"\xdb\x01\n\x04\x43\x61ll\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x1a\n\x12\x63reated_by_user_id\x18\x03 \x01(\t\x12\x14\n\x0chost_user_id\x18\x04 \x01(\t\x12\'\n\x06\x63ustom\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb0\x02\n\x0bParticipant\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.stream.video.sfu.models.User\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0e\n\x06online\x18\x03 \x01(\x08\x12\'\n\x06\x63ustom\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05video\x18\x05 \x01(\x08\x12\r\n\x05\x61udio\x18\x06 \x01(\x08\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsession_id\x18\t \x01(\t\x12\x1b\n\x13track_lookup_prefix\x18\n \x01(\t\"\xa1\x01\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05teams\x18\x02 \x03(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\'\n\x06\x63ustom\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\"^\n\rStreamQuality\x12<\n\rvideo_quality\x18\x01 \x01(\x0e\x32%.stream.video.sfu.models.VideoQuality\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"/\n\x0eVideoDimension\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\"l\n\nVideoLayer\x12\x0b\n\x03rid\x18\x01 \x01(\t\x12@\n\x0fvideo_dimension\x18\x02 \x01(\x0b\x32\'.stream.video.sfu.models.VideoDimension\x12\x0f\n\x07\x62itrate\x18\x04 \x01(\r\"v\n\x12SimulcastCodecInfo\x12\x11\n\tmime_type\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\t\x12\x33\n\x06layers\x18\x04 \x03(\x0b\x32#.stream.video.sfu.models.VideoLayer\"T\n\x05\x43odec\x12\x0c\n\x04mime\x18\x01 \x01(\t\x12\x11\n\tfmtp_line\x18\x02 \x01(\t\x12\x12\n\nclock_rate\x18\x03 \x01(\r\x12\x16\n\x0ehw_accelerated\x18\x04 \x01(\x08\"o\n\x0b\x41udioCodecs\x12/\n\x07\x65ncodes\x18\x01 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12/\n\x07\x64\x65\x63odes\x18\x02 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\"o\n\x0bVideoCodecs\x12/\n\x07\x65ncodes\x18\x01 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\x12/\n\x07\x64\x65\x63odes\x18\x02 \x03(\x0b\x32\x1e.stream.video.sfu.models.Codec\"\xae\x01\n\rCodecSettings\x12\x33\n\x05\x61udio\x18\x01 \x01(\x0b\x32$.stream.video.sfu.models.AudioCodecs\x12\x33\n\x05video\x18\x02 \x01(\x0b\x32$.stream.video.sfu.models.VideoCodecs\x12\x33\n\x06layers\x18\x03 \x03(\x0b\x32#.stream.video.sfu.models.VideoLayer\"m\n\nICETrickle\x12\x34\n\tpeer_type\x18\x01 \x01(\x0e\x32!.stream.video.sfu.models.PeerType\x12\x15\n\rice_candidate\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t*I\n\x08PeerType\x12#\n\x1fPEER_TYPE_PUBLISHER_UNSPECIFIED\x10\x00\x12\x18\n\x14PEER_TYPE_SUBSCRIBER\x10\x01*u\n\x11\x43onnectionQuality\x12&\n\"CONNECTION_QUALITY_BAD_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONNECTION_QUALITY_POOR\x10\x01\x12\x1b\n\x17\x43ONNECTION_QUALITY_GOOD\x10\x02*`\n\x0cVideoQuality\x12!\n\x1dVIDEO_QUALITY_LOW_UNSPECIFIED\x10\x00\x12\x15\n\x11VIDEO_QUALITY_MID\x10\x01\x12\x16\n\x12VIDEO_QUALITY_HIGH\x10\x02\x42\x31\x42\x0bSfuModelsV1P\x01Z\nsfu_models\xaa\x02\x13Stream.Video.v1.Sfub\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.models.models_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\013SfuModelsV1P\001Z\nsfu_models\252\002\023Stream.Video.v1.Sfu'
  _PEERTYPE._serialized_start=1862
  _PEERTYPE._serialized_end=1935
  _CONNECTIONQUALITY._serialized_start=1937
  _CONNECTIONQUALITY._serialized_end=2054
  _VIDEOQUALITY._serialized_start=2056
  _VIDEOQUALITY._serialized_end=2152
  _CALLSTATE._serialized_start=121
  _CALLSTATE._serialized_end=192
  _CALL._serialized_start=195
  _CALL._serialized_end=414
  _PARTICIPANT._serialized_start=417
  _PARTICIPANT._serialized_end=721
  _USER._serialized_start=724
  _USER._serialized_end=885
  _STREAMQUALITY._serialized_start=887
  _STREAMQUALITY._serialized_end=981
  _VIDEODIMENSION._serialized_start=983
  _VIDEODIMENSION._serialized_end=1030
  _VIDEOLAYER._serialized_start=1032
  _VIDEOLAYER._serialized_end=1140
  _SIMULCASTCODECINFO._serialized_start=1142
  _SIMULCASTCODECINFO._serialized_end=1260
  _CODEC._serialized_start=1262
  _CODEC._serialized_end=1346
  _AUDIOCODECS._serialized_start=1348
  _AUDIOCODECS._serialized_end=1459
  _VIDEOCODECS._serialized_start=1461
  _VIDEOCODECS._serialized_end=1572
  _CODECSETTINGS._serialized_start=1575
  _CODECSETTINGS._serialized_end=1749
  _ICETRICKLE._serialized_start=1751
  _ICETRICKLE._serialized_end=1860
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing
import video.sfu.models.models_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UpdateVideoQualityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_QUALITIES_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    @property
    def stream_qualities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.sfu.models.models_pb2.StreamQuality]: ...
    session_id: builtins.str
    def __init__(
        self,
        *,
        stream_qualities: collections.abc.Iterable[video.sfu.models.models_pb2.StreamQuality] | None = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_id", b"session_id", "stream_qualities", b"stream_qualities"]) -> None: ...

global___UpdateVideoQualityRequest = UpdateVideoQualityRequest

class UpdateVideoQualityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateVideoQualityResponse = UpdateVideoQualityResponse

class UpdateMuteStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    AUDIO_MUTE_CHANGED_FIELD_NUMBER: builtins.int
    VIDEO_MUTE_CHANGED_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    @property
    def audio_mute_changed(self) -> global___AudioMuteChanged: ...
    @property
    def video_mute_changed(self) -> global___VideoMuteChanged: ...
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        audio_mute_changed: global___AudioMuteChanged | None = ...,
        video_mute_changed: global___VideoMuteChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio_mute_changed", b"audio_mute_changed", "mute", b"mute", "video_mute_changed", b"video_mute_changed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_mute_changed", b"audio_mute_changed", "mute", b"mute", "session_id", b"session_id", "video_mute_changed", b"video_mute_changed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["mute", b"mute"]) -> typing_extensions.Literal["audio_mute_changed", "video_mute_changed"] | None: ...

global___UpdateMuteStateRequest = UpdateMuteStateRequest

class UpdateMuteStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateMuteStateResponse = UpdateMuteStateResponse

class AudioMuteChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTED_FIELD_NUMBER: builtins.int
    muted: builtins.bool
    def __init__(
        self,
        *,
        muted: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["muted", b"muted"]) -> None: ...

global___AudioMuteChanged = AudioMuteChanged

class VideoMuteChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTED_FIELD_NUMBER: builtins.int
    muted: builtins.bool
    def __init__(
        self,
        *,
        muted: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["muted", b"muted"]) -> None: ...

global___VideoMuteChanged = VideoMuteChanged

class UpdateSubscriptionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class SubscriptionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.sfu.models.models_pb2.VideoDimension: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.sfu.models.models_pb2.VideoDimension | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    @property
    def subscriptions(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.sfu.models.models_pb2.VideoDimension]:
        """maps stream user_ids to its size"""
    session_id: builtins.str
    def __init__(
        self,
        *,
        subscriptions: collections.abc.Mapping[builtins.str, video.sfu.models.models_pb2.VideoDimension] | None = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_id", b"session_id", "subscriptions", b"subscriptions"]) -> None: ...

global___UpdateSubscriptionsRequest = UpdateSubscriptionsRequest

class SendAnswerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEER_TYPE_FIELD_NUMBER: builtins.int
    SDP_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    peer_type: video.sfu.models.models_pb2.PeerType.ValueType
    sdp: builtins.str
    session_id: builtins.str
    def __init__(
        self,
        *,
        peer_type: video.sfu.models.models_pb2.PeerType.ValueType = ...,
        sdp: builtins.str = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["peer_type", b"peer_type", "sdp", b"sdp", "session_id", b"session_id"]) -> None: ...

global___SendAnswerRequest = SendAnswerRequest

class SendAnswerResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SendAnswerResponse = SendAnswerResponse

class IceCandidateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISHER_FIELD_NUMBER: builtins.int
    CANDIDATE_FIELD_NUMBER: builtins.int
    SDP_MID_FIELD_NUMBER: builtins.int
    SDP_MLINE_INDEX_FIELD_NUMBER: builtins.int
    USERNAME_FRAGMENT_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    publisher: builtins.bool
    """TODO: use PeerTYPE!"""
    candidate: builtins.str
    sdp_mid: builtins.str
    sdp_mline_index: builtins.int
    username_fragment: builtins.str
    session_id: builtins.str
    def __init__(
        self,
        *,
        publisher: builtins.bool = ...,
        candidate: builtins.str = ...,
        sdp_mid: builtins.str | None = ...,
        sdp_mline_index: builtins.int | None = ...,
        username_fragment: builtins.str | None = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_sdp_mid", b"_sdp_mid", "_sdp_mline_index", b"_sdp_mline_index", "_username_fragment", b"_username_fragment", "sdp_mid", b"sdp_mid", "sdp_mline_index", b"sdp_mline_index", "username_fragment", b"username_fragment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_sdp_mid", b"_sdp_mid", "_sdp_mline_index", b"_sdp_mline_index", "_username_fragment", b"_username_fragment", "candidate", b"candidate", "publisher", b"publisher", "sdp_mid", b"sdp_mid", "sdp_mline_index", b"sdp_mline_index", "session_id", b"session_id", "username_fragment", b"username_fragment"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_sdp_mid", b"_sdp_mid"]) -> typing_extensions.Literal["sdp_mid"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_sdp_mline_index", b"_sdp_mline_index"]) -> typing_extensions.Literal["sdp_mline_index"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_username_fragment", b"_username_fragment"]) -> typing_extensions.Literal["username_fragment"] | None: ...

global___IceCandidateRequest = IceCandidateRequest

class ICETrickleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ICETrickleResponse = ICETrickleResponse

class UpdateSubscriptionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateSubscriptionsResponse = UpdateSubscriptionsResponse

class SetPublisherRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDP_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    sdp: builtins.str
    """sdp offer"""
    session_id: builtins.str
    def __init__(
        self,
        *,
        sdp: builtins.str = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp", b"sdp", "session_id", b"session_id"]) -> None: ...

global___SetPublisherRequest = SetPublisherRequest

class SetPublisherResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDP_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    sdp: builtins.str
    """sdp answer"""
    session_id: builtins.str
    def __init__(
        self,
        *,
        sdp: builtins.str = ...,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp", b"sdp", "session_id", b"session_id"]) -> None: ...

global___SetPublisherResponse = SetPublisherResponse

class ConnectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDP_OFFER_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    sdp_offer: builtins.str
    """peer connection sdp offer"""
    token: builtins.str
    """token used for authentication"""
    def __init__(
        self,
        *,
        sdp_offer: builtins.str = ...,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp_offer", b"sdp_offer", "token", b"token"]) -> None: ...

global___ConnectRequest = ConnectRequest

class ConnectResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDP_ANSWER_FIELD_NUMBER: builtins.int
    sdp_answer: builtins.str
    """sdp answer"""
    def __init__(
        self,
        *,
        sdp_answer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp_answer", b"sdp_answer"]) -> None: ...

global___ConnectResponse = ConnectResponse

class SignalRequest(google.protobuf.message.Message):
    """Signaling related payload, all these messages will be exchanged using signaling channel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIBE_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    @property
    def subscribe(self) -> global___SubscribeRequest: ...
    @property
    def publish(self) -> global___PublishRequest: ...
    def __init__(
        self,
        *,
        subscribe: global___SubscribeRequest | None = ...,
        publish: global___PublishRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event_payload", b"event_payload", "publish", b"publish", "subscribe", b"subscribe"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_payload", b"event_payload", "publish", b"publish", "subscribe", b"subscribe"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event_payload", b"event_payload"]) -> typing_extensions.Literal["subscribe", "publish"] | None: ...

global___SignalRequest = SignalRequest

class SignalEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIBE_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    @property
    def subscribe(self) -> global___SubscribeResponse: ...
    @property
    def publish(self) -> global___PublishResponse: ...
    def __init__(
        self,
        *,
        subscribe: global___SubscribeResponse | None = ...,
        publish: global___PublishResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event_payload", b"event_payload", "publish", b"publish", "subscribe", b"subscribe"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_payload", b"event_payload", "publish", b"publish", "subscribe", b"subscribe"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event_payload", b"event_payload"]) -> typing_extensions.Literal["subscribe", "publish"] | None: ...

global___SignalEvent = SignalEvent

class SubscribeRequest(google.protobuf.message.Message):
    """SubscribeRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    SDP_OFFER_FIELD_NUMBER: builtins.int
    QUALITY_FIELD_NUMBER: builtins.int
    token: builtins.str
    sdp_offer: builtins.str
    quality: builtins.str
    """preferred quality"""
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        sdp_offer: builtins.str = ...,
        quality: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["quality", b"quality", "sdp_offer", b"sdp_offer", "token", b"token"]) -> None: ...

global___SubscribeRequest = SubscribeRequest

class SubscribeResponse(google.protobuf.message.Message):
    """SubscribeResponse"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    quality: builtins.str
    """preferred quality"""
    def __init__(
        self,
        *,
        quality: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["quality", b"quality"]) -> None: ...

global___SubscribeResponse = SubscribeResponse

class PublishRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    SDP_OFFER_FIELD_NUMBER: builtins.int
    token: builtins.str
    sdp_offer: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        sdp_offer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp_offer", b"sdp_offer", "token", b"token"]) -> None: ...

global___PublishRequest = PublishRequest

class PublishResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDP_ANSWER_FIELD_NUMBER: builtins.int
    sdp_answer: builtins.str
    def __init__(
        self,
        *,
        sdp_answer: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdp_answer", b"sdp_answer"]) -> None: ...

global___PublishResponse = PublishResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import video.coordinator.call_v1.call_pb2
import video.coordinator.member_v1.member_pb2
import video.coordinator.user_v1.user_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CallEnvelope(google.protobuf.message.Message):
    """CallEnvelope contains Call and all related information to it
    Only used in reponse types that return a single call
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UsersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.user_v1.user_pb2.User: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.user_v1.user_pb2.User | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    CALL_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.user_v1.user_pb2.User]:
        """All users referenced in the response"""
    @property
    def call(self) -> video.coordinator.call_v1.call_pb2.Call:
        """Call object"""
    @property
    def details(self) -> video.coordinator.call_v1.call_pb2.CallDetails:
        """Call details"""
    def __init__(
        self,
        *,
        users: collections.abc.Mapping[builtins.str, video.coordinator.user_v1.user_pb2.User] | None = ...,
        call: video.coordinator.call_v1.call_pb2.Call | None = ...,
        details: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "details", b"details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "details", b"details", "users", b"users"]) -> None: ...

global___CallEnvelope = CallEnvelope

class CallsEnvelope(google.protobuf.message.Message):
    """CallsEnvelope contains list of calls and all related information to them
    Only used in response types that return list of calls
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UsersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.user_v1.user_pb2.User: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.user_v1.user_pb2.User | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class CallsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.call_v1.call_pb2.Call: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.call_v1.call_pb2.Call | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class DetailsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.call_v1.call_pb2.CallDetails: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.call_v1.call_pb2.CallDetails | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    CALL_CIDS_FIELD_NUMBER: builtins.int
    CALLS_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.user_v1.user_pb2.User]:
        """All users referenced in the response"""
    @property
    def call_cids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Ordered list of Call.call_cid"""
    @property
    def calls(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.call_v1.call_pb2.Call]:
        """Call objects, indexed by Call.call_cid"""
    @property
    def details(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.call_v1.call_pb2.CallDetails]:
        """Call details, indexed by Call.call_cid"""
    def __init__(
        self,
        *,
        users: collections.abc.Mapping[builtins.str, video.coordinator.user_v1.user_pb2.User] | None = ...,
        call_cids: collections.abc.Iterable[builtins.str] | None = ...,
        calls: collections.abc.Mapping[builtins.str, video.coordinator.call_v1.call_pb2.Call] | None = ...,
        details: collections.abc.Mapping[builtins.str, video.coordinator.call_v1.call_pb2.CallDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_cids", b"call_cids", "calls", b"calls", "details", b"details", "users", b"users"]) -> None: ...

global___CallsEnvelope = CallsEnvelope

class MembersEnvelope(google.protobuf.message.Message):
    """CallsEnvelope contains list of members and all related information to them
    Only used in response types that return list of members
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UsersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.user_v1.user_pb2.User: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.user_v1.user_pb2.User | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class MembersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.member_v1.member_pb2.Member: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.member_v1.member_pb2.Member | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    MEMBER_USER_IDS_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.user_v1.user_pb2.User]:
        """All users referenced in the response"""
    @property
    def member_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Ordered list of Member.user_id"""
    @property
    def members(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.member_v1.member_pb2.Member]:
        """Map of members indexed by Member.user_id"""
    def __init__(
        self,
        *,
        users: collections.abc.Mapping[builtins.str, video.coordinator.user_v1.user_pb2.User] | None = ...,
        member_user_ids: collections.abc.Iterable[builtins.str] | None = ...,
        members: collections.abc.Mapping[builtins.str, video.coordinator.member_v1.member_pb2.Member] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["member_user_ids", b"member_user_ids", "members", b"members", "users", b"users"]) -> None: ...

global___MembersEnvelope = MembersEnvelope



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RecordingStorage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RecordingStorageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RecordingStorage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RECORDING_STORAGE_S3_UNSPECIFIED: _RecordingStorage.ValueType  # 0

class RecordingStorage(_RecordingStorage, metaclass=_RecordingStorageEnumTypeWrapper): ...

RECORDING_STORAGE_S3_UNSPECIFIED: RecordingStorage.ValueType  # 0
global___RecordingStorage = RecordingStorage

class Recording(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_TYPE_FIELD_NUMBER: builtins.int
    CALL_ID_FIELD_NUMBER: builtins.int
    S3_FILE_URL_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    STOP_TIME_FIELD_NUMBER: builtins.int
    call_type: builtins.str
    call_id: builtins.str
    s3_file_url: builtins.str
    start_time: builtins.str
    stop_time: builtins.str
    def __init__(
        self,
        *,
        call_type: builtins.str = ...,
        call_id: builtins.str = ...,
        s3_file_url: builtins.str = ...,
        start_time: builtins.str = ...,
        stop_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_id", b"call_id", "call_type", b"call_type", "s3_file_url", b"s3_file_url", "start_time", b"start_time", "stop_time", b"stop_time"]) -> None: ...

global___Recording = Recording

class File(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    COMPOSITE_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    type: builtins.str
    composite: builtins.bool
    user_id: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        composite: builtins.bool = ...,
        user_id: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["composite", b"composite", "type", b"type", "url", b"url", "user_id", b"user_id"]) -> None: ...

global___File = File

class RecordBroadcast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPOSITE_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    composite: builtins.bool
    """If true merge all audio and video, if false split them."""
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """List of recorded files."""
    def __init__(
        self,
        *,
        composite: builtins.bool = ...,
        files: collections.abc.Iterable[global___File] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["composite", b"composite", "files", b"files"]) -> None: ...

global___RecordBroadcast = RecordBroadcast

class RecordingStorageOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_FIELD_NUMBER: builtins.int
    ACCESS_KEY_FIELD_NUMBER: builtins.int
    SECRET_KEY_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    storage: global___RecordingStorage.ValueType
    access_key: builtins.str
    secret_key: builtins.str
    bucket_name: builtins.str
    region: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        storage: global___RecordingStorage.ValueType = ...,
        access_key: builtins.str = ...,
        secret_key: builtins.str = ...,
        bucket_name: builtins.str = ...,
        region: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "bucket_name", b"bucket_name", "path", b"path", "region", b"region", "secret_key", b"secret_key", "storage", b"storage"]) -> None: ...

global___RecordingStorageOptions = RecordingStorageOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/sfu/cascading_rpc/gossip.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/sfu/cascading_rpc/gossip.proto\x12\x17stream.video.sfu.gossip\"@\n\x0cSubscription\x12\x14\n\x0cpublisher_id\x18\x01 \x01(\t\x12\x0b\n\x03rid\x18\x02 \x01(\t\x12\r\n\x05\x63oded\x18\x03 \x01(\t\"\\\n\x0bParticipant\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12<\n\rsubscriptions\x18\x02 \x03(\x0b\x32%.stream.video.sfu.gossip.Subscription\"Y\n\tCallState\x12:\n\x0cparticipants\x18\x01 \x03(\x0b\x32$.stream.video.sfu.gossip.Participant\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"\\\n\x0fJoinCallRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x37\n\x0blocal_state\x18\x02 \x01(\x0b\x32\".stream.video.sfu.gossip.CallState\"b\n\x10JoinCallResponse\x12\x15\n\rsfu_addresses\x18\x01 \x03(\t\x12\x37\n\x0blocal_state\x18\x02 \x01(\x0b\x32\".stream.video.sfu.gossip.CallState\"\x15\n\x13GetCallStateRequest\"O\n\x14GetCallStateResponse\x12\x37\n\x0blocal_state\x18\x01 \x01(\x0b\x32\".stream.video.sfu.gossip.CallState\"\x12\n\x10\x41udioMuteChanged\"\r\n\x0bHealthcheck\"\x12\n\x10VideoMuteChanged\"\x8f\x02\n\x10SendEventRequest\x12\x10\n\x08\x63\x61ll_cid\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x03\x12<\n\x0chealth_check\x18\x03 \x01(\x0b\x32$.stream.video.sfu.gossip.HealthcheckH\x00\x12G\n\x12\x61udio_mute_changed\x18\x04 \x01(\x0b\x32).stream.video.sfu.gossip.AudioMuteChangedH\x00\x12G\n\x12video_mute_changed\x18\x05 \x01(\x0b\x32).stream.video.sfu.gossip.VideoMuteChangedH\x00\x42\x07\n\x05\x65vent\"\x13\n\x11SendEventResponse2\xbd\x02\n\tGossipRPC\x12_\n\x08JoinCall\x12(.stream.video.sfu.gossip.JoinCallRequest\x1a).stream.video.sfu.gossip.JoinCallResponse\x12\x62\n\tSendEvent\x12).stream.video.sfu.gossip.SendEventRequest\x1a*.stream.video.sfu.gossip.SendEventResponse\x12k\n\x0cGetCallState\x12,.stream.video.sfu.gossip.GetCallStateRequest\x1a-.stream.video.sfu.gossip.GetCallStateResponseB\x10Z\x0esfu_gossip_rpcb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.sfu.cascading_rpc.gossip_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\016sfu_gossip_rpc'
  _SUBSCRIPTION._serialized_start=65
  _SUBSCRIPTION._serialized_end=129
  _PARTICIPANT._serialized_start=131
  _PARTICIPANT._serialized_end=223
  _CALLSTATE._serialized_start=225
  _CALLSTATE._serialized_end=314
  _JOINCALLREQUEST._serialized_start=316
  _JOINCALLREQUEST._serialized_end=408
  _JOINCALLRESPONSE._serialized_start=410
  _JOINCALLRESPONSE._serialized_end=508
  _GETCALLSTATEREQUEST._serialized_start=510
  _GETCALLSTATEREQUEST._serialized_end=531
  _GETCALLSTATERESPONSE._serialized_start=533
  _GETCALLSTATERESPONSE._serialized_end=612
  _AUDIOMUTECHANGED._serialized_start=614
  _AUDIOMUTECHANGED._serialized_end=632
  _HEALTHCHECK._serialized_start=634
  _HEALTHCHECK._serialized_end=647
  _VIDEOMUTECHANGED._serialized_start=649
  _VIDEOMUTECHANGED._serialized_end=667
  _SENDEVENTREQUEST._serialized_start=670
  _SENDEVENTREQUEST._serialized_end=941
  _SENDEVENTRESPONSE._serialized_start=943
  _SENDEVENTRESPONSE._serialized_end=962
  _GOSSIPRPC._serialized_start=965
  _GOSSIPRPC._serialized_end=1282
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import video.coordinator.app_v1.app_pb2
import video.coordinator.broadcast_v1.broadcast_pb2
import video.coordinator.call_v1.call_pb2
import video.coordinator.push_v1.push_pb2
import video.coordinator.recording_v1.recording_pb2
import video.coordinator.server_v1_rpc.envelopes_pb2
import video.coordinator.stat_v1.stat_pb2
import video.coordinator.user_v1.user_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetAppRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAppRequest = GetAppRequest

class GetAppResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_FIELD_NUMBER: builtins.int
    @property
    def app(self) -> video.coordinator.app_v1.app_pb2.App: ...
    def __init__(
        self,
        *,
        app: video.coordinator.app_v1.app_pb2.App | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app", b"app"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app"]) -> None: ...

global___GetAppResponse = GetAppResponse

class UpdateAppRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WEBHOOK_FIELD_NUMBER: builtins.int
    @property
    def webhook(self) -> video.coordinator.app_v1.app_pb2.WebhookSettings: ...
    def __init__(
        self,
        *,
        webhook: video.coordinator.app_v1.app_pb2.WebhookSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["webhook", b"webhook"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["webhook", b"webhook"]) -> None: ...

global___UpdateAppRequest = UpdateAppRequest

class UpdateAppResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_FIELD_NUMBER: builtins.int
    @property
    def app(self) -> video.coordinator.app_v1.app_pb2.App: ...
    def __init__(
        self,
        *,
        app: video.coordinator.app_v1.app_pb2.App | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app", b"app"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app", b"app"]) -> None: ...

global___UpdateAppResponse = UpdateAppResponse

class PushProviderInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    APN_FIELD_NUMBER: builtins.int
    FIREBASE_FIELD_NUMBER: builtins.int
    HUAWEI_FIELD_NUMBER: builtins.int
    XIAOMI_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def apn(self) -> video.coordinator.push_v1.push_pb2.ApnCredentials: ...
    @property
    def firebase(self) -> video.coordinator.push_v1.push_pb2.FirebaseCredentials: ...
    @property
    def huawei(self) -> video.coordinator.push_v1.push_pb2.HuaweiCredentials: ...
    @property
    def xiaomi(self) -> video.coordinator.push_v1.push_pb2.XiaomiCredentials: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        apn: video.coordinator.push_v1.push_pb2.ApnCredentials | None = ...,
        firebase: video.coordinator.push_v1.push_pb2.FirebaseCredentials | None = ...,
        huawei: video.coordinator.push_v1.push_pb2.HuaweiCredentials | None = ...,
        xiaomi: video.coordinator.push_v1.push_pb2.XiaomiCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apn", b"apn", "credentials", b"credentials", "firebase", b"firebase", "huawei", b"huawei", "xiaomi", b"xiaomi"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apn", b"apn", "credentials", b"credentials", "firebase", b"firebase", "huawei", b"huawei", "id", b"id", "xiaomi", b"xiaomi"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["apn", "firebase", "huawei", "xiaomi"] | None: ...

global___PushProviderInput = PushProviderInput

class CreatePushProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_FIELD_NUMBER: builtins.int
    @property
    def input(self) -> global___PushProviderInput: ...
    def __init__(
        self,
        *,
        input: global___PushProviderInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input", b"input"]) -> None: ...

global___CreatePushProviderRequest = CreatePushProviderRequest

class CreatePushProviderResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def provider(self) -> video.coordinator.push_v1.push_pb2.PushProvider: ...
    def __init__(
        self,
        *,
        provider: video.coordinator.push_v1.push_pb2.PushProvider | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider", b"provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["provider", b"provider"]) -> None: ...

global___CreatePushProviderResponse = CreatePushProviderResponse

class GetPushProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GetPushProviderRequest = GetPushProviderRequest

class GetPushProviderResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def provider(self) -> video.coordinator.push_v1.push_pb2.PushProvider: ...
    def __init__(
        self,
        *,
        provider: video.coordinator.push_v1.push_pb2.PushProvider | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider", b"provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["provider", b"provider"]) -> None: ...

global___GetPushProviderResponse = GetPushProviderResponse

class QueryPushProvidersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryPushProvidersRequest = QueryPushProvidersRequest

class QueryPushProvidersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROVIDERS_FIELD_NUMBER: builtins.int
    @property
    def providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.push_v1.push_pb2.PushProvider]: ...
    def __init__(
        self,
        *,
        providers: collections.abc.Iterable[video.coordinator.push_v1.push_pb2.PushProvider] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["providers", b"providers"]) -> None: ...

global___QueryPushProvidersResponse = QueryPushProvidersResponse

class UpdatePushProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_FIELD_NUMBER: builtins.int
    @property
    def input(self) -> global___PushProviderInput: ...
    def __init__(
        self,
        *,
        input: global___PushProviderInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input", b"input"]) -> None: ...

global___UpdatePushProviderRequest = UpdatePushProviderRequest

class UpdatePushProviderResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def provider(self) -> video.coordinator.push_v1.push_pb2.PushProvider: ...
    def __init__(
        self,
        *,
        provider: video.coordinator.push_v1.push_pb2.PushProvider | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider", b"provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["provider", b"provider"]) -> None: ...

global___UpdatePushProviderResponse = UpdatePushProviderResponse

class DeletePushProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DeletePushProviderRequest = DeletePushProviderRequest

class DeletePushProviderResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeletePushProviderResponse = DeletePushProviderResponse

class DeleteCallTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """the name of the call type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteCallTypeRequest = DeleteCallTypeRequest

class DeleteCallTypeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteCallTypeResponse = DeleteCallTypeResponse

class CreateCallTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """the name of the call type, must be unique for the application"""
    @property
    def options(self) -> video.coordinator.call_v1.call_pb2.CallOptions: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        options: video.coordinator.call_v1.call_pb2.CallOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "options", b"options"]) -> None: ...

global___CreateCallTypeRequest = CreateCallTypeRequest

class CreateCallTypeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_TYPE_FIELD_NUMBER: builtins.int
    @property
    def call_type(self) -> video.coordinator.call_v1.call_pb2.CallType:
        """the call type updated"""
    def __init__(
        self,
        *,
        call_type: video.coordinator.call_v1.call_pb2.CallType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call_type", b"call_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_type", b"call_type"]) -> None: ...

global___CreateCallTypeResponse = CreateCallTypeResponse

class GetCallTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetCallTypeRequest = GetCallTypeRequest

class GetCallTypeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_TYPE_FIELD_NUMBER: builtins.int
    @property
    def call_type(self) -> video.coordinator.call_v1.call_pb2.CallType:
        """the call type updated"""
    def __init__(
        self,
        *,
        call_type: video.coordinator.call_v1.call_pb2.CallType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call_type", b"call_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_type", b"call_type"]) -> None: ...

global___GetCallTypeResponse = GetCallTypeResponse

class QueryCallTypesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryCallTypesRequest = QueryCallTypesRequest

class QueryCallTypesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_TYPES_FIELD_NUMBER: builtins.int
    @property
    def call_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.call_v1.call_pb2.CallType]: ...
    def __init__(
        self,
        *,
        call_types: collections.abc.Iterable[video.coordinator.call_v1.call_pb2.CallType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_types", b"call_types"]) -> None: ...

global___QueryCallTypesResponse = QueryCallTypesResponse

class UpdateCallTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """the name of the call type, must be unique for the application"""
    @property
    def options(self) -> video.coordinator.call_v1.call_pb2.CallOptions: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        options: video.coordinator.call_v1.call_pb2.CallOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "options", b"options"]) -> None: ...

global___UpdateCallTypeRequest = UpdateCallTypeRequest

class UpdateCallTypeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_TYPE_FIELD_NUMBER: builtins.int
    @property
    def call_type(self) -> video.coordinator.call_v1.call_pb2.CallType:
        """the call type updated"""
    def __init__(
        self,
        *,
        call_type: video.coordinator.call_v1.call_pb2.CallType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call_type", b"call_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_type", b"call_type"]) -> None: ...

global___UpdateCallTypeResponse = UpdateCallTypeResponse

class CreateCallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    PARTICIPANT_IDS_FIELD_NUMBER: builtins.int
    HLS_BROADCAST_FIELD_NUMBER: builtins.int
    RTMP_FIELD_NUMBER: builtins.int
    RECORDING_FIELD_NUMBER: builtins.int
    NOTIFY_FIELD_NUMBER: builtins.int
    type: builtins.str
    """The call type.
    Required.
    """
    id: builtins.str
    """The call id, if not provided a unique value will be generated based on UUID v4.
    Required.
    """
    custom_json: builtins.bytes
    """Call custom data."""
    @property
    def participant_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The list of participant ids."""
    @property
    def hls_broadcast(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """HLS broadcast, overrides the default call type setting if provided."""
    @property
    def rtmp(self) -> video.coordinator.broadcast_v1.broadcast_pb2.RTMPOptions:
        """Request video to be forwarded to a list of RTMP servers."""
    @property
    def recording(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """The recording option, overrides the default call type setting if provided."""
    @property
    def notify(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """The ring option, overrides the default call type setting if provided."""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        participant_ids: collections.abc.Iterable[builtins.str] | None = ...,
        hls_broadcast: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        rtmp: video.coordinator.broadcast_v1.broadcast_pb2.RTMPOptions | None = ...,
        recording: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        notify: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hls_broadcast", b"hls_broadcast", "notify", b"notify", "recording", b"recording", "rtmp", b"rtmp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_json", b"custom_json", "hls_broadcast", b"hls_broadcast", "id", b"id", "notify", b"notify", "participant_ids", b"participant_ids", "recording", b"recording", "rtmp", b"rtmp", "type", b"type"]) -> None: ...

global___CreateCallRequest = CreateCallRequest

class CreateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEAMS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CUSTOM_JSON_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def teams(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    custom_json: builtins.bytes
    name: builtins.str
    image_url: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        teams: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        custom_json: builtins.bytes = ...,
        name: builtins.str = ...,
        image_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_json", b"custom_json", "id", b"id", "image_url", b"image_url", "name", b"name", "role", b"role", "teams", b"teams"]) -> None: ...

global___CreateUserRequest = CreateUserRequest

class CreateOrUpdateUsersRequest(google.protobuf.message.Message):
    """CreateOrUpdateUsersRequest runs a partial update or create on the list of users
    specify replace = true to do a hard update instead of partial update.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    FULL_UPDATE_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateUserRequest]: ...
    full_update: builtins.bool
    """Full update (defaults to false and does a partial update)."""
    def __init__(
        self,
        *,
        users: collections.abc.Iterable[global___CreateUserRequest] | None = ...,
        full_update: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["full_update", b"full_update", "users", b"users"]) -> None: ...

global___CreateOrUpdateUsersRequest = CreateOrUpdateUsersRequest

class CreateOrUpdateUsersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.user_v1.user_pb2.User]: ...
    def __init__(
        self,
        *,
        users: collections.abc.Iterable[video.coordinator.user_v1.user_pb2.User] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["users", b"users"]) -> None: ...

global___CreateOrUpdateUsersResponse = CreateOrUpdateUsersResponse

class DeleteUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DELETE_CALL_HISTORY_FIELD_NUMBER: builtins.int
    DELETE_RECORDINGS_FIELD_NUMBER: builtins.int
    id: builtins.str
    delete_call_history: builtins.bool
    delete_recordings: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        delete_call_history: builtins.bool = ...,
        delete_recordings: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_call_history", b"delete_call_history", "delete_recordings", b"delete_recordings", "id", b"id"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest

class ExportUserRequest(google.protobuf.message.Message):
    """TODO: do we support both soft and hard delete"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ExportUserRequest = ExportUserRequest

class ExportUserResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_USER_FIELD_NUMBER: builtins.int
    @property
    def export_user(self) -> video.coordinator.server_v1_rpc.envelopes_pb2.ExportUserEnvelope: ...
    def __init__(
        self,
        *,
        export_user: video.coordinator.server_v1_rpc.envelopes_pb2.ExportUserEnvelope | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["export_user", b"export_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_user", b"export_user"]) -> None: ...

global___ExportUserResponse = ExportUserResponse

class DeleteUserResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DeleteUserResponse = DeleteUserResponse

class CreateUserResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> video.coordinator.user_v1.user_pb2.User: ...
    def __init__(
        self,
        *,
        user: video.coordinator.user_v1.user_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user", b"user"]) -> None: ...

global___CreateUserResponse = CreateUserResponse

class UserCapability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    action: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description"]) -> None: ...

global___UserCapability = UserCapability

class StartBroadcastRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_ID_FIELD_NUMBER: builtins.int
    CALL_TYPE_FIELD_NUMBER: builtins.int
    HLS_BROADCAST_FIELD_NUMBER: builtins.int
    RTMP_FIELD_NUMBER: builtins.int
    call_id: builtins.str
    """Call id and type."""
    call_type: builtins.str
    hls_broadcast: builtins.bool
    """Toggles HLS broadcasting on/off."""
    @property
    def rtmp(self) -> video.coordinator.broadcast_v1.broadcast_pb2.RTMPOptions:
        """Enables rtmp broadcasting."""
    def __init__(
        self,
        *,
        call_id: builtins.str = ...,
        call_type: builtins.str = ...,
        hls_broadcast: builtins.bool = ...,
        rtmp: video.coordinator.broadcast_v1.broadcast_pb2.RTMPOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rtmp", b"rtmp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_id", b"call_id", "call_type", b"call_type", "hls_broadcast", b"hls_broadcast", "rtmp", b"rtmp"]) -> None: ...

global___StartBroadcastRequest = StartBroadcastRequest

class StartBroadcastResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BROADCAST_FIELD_NUMBER: builtins.int
    @property
    def broadcast(self) -> video.coordinator.broadcast_v1.broadcast_pb2.Broadcast: ...
    def __init__(
        self,
        *,
        broadcast: video.coordinator.broadcast_v1.broadcast_pb2.Broadcast | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["broadcast", b"broadcast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["broadcast", b"broadcast"]) -> None: ...

global___StartBroadcastResponse = StartBroadcastResponse

class StopBroadcastRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopBroadcastRequest = StopBroadcastRequest

class StopBroadcastResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StopBroadcastResponse = StopBroadcastResponse

class StoreLatencyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StoreLatencyRequest = StoreLatencyRequest

class StoreLatencyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StoreLatencyResponse = StoreLatencyResponse

class StartRecordingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_TYPE_FIELD_NUMBER: builtins.int
    CALL_ID_FIELD_NUMBER: builtins.int
    call_type: builtins.str
    call_id: builtins.str
    def __init__(
        self,
        *,
        call_type: builtins.str = ...,
        call_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_id", b"call_id", "call_type", b"call_type"]) -> None: ...

global___StartRecordingRequest = StartRecordingRequest

class StartRecordingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StartRecordingResponse = StartRecordingResponse

class StopRecordingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_TYPE_FIELD_NUMBER: builtins.int
    CALL_ID_FIELD_NUMBER: builtins.int
    call_type: builtins.str
    call_id: builtins.str
    def __init__(
        self,
        *,
        call_type: builtins.str = ...,
        call_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_id", b"call_id", "call_type", b"call_type"]) -> None: ...

global___StopRecordingRequest = StopRecordingRequest

class StopRecordingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S3_FILE_URL_FIELD_NUMBER: builtins.int
    s3_file_url: builtins.str
    def __init__(
        self,
        *,
        s3_file_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["s3_file_url", b"s3_file_url"]) -> None: ...

global___StopRecordingResponse = StopRecordingResponse

class GetRecordingsRequest(google.protobuf.message.Message):
    """TODO: how do we do filtering and pagination with proto?
    here we need to be able to filter, sort and limit by
    call id, call custom attribute, call creation time, call including a user, call by type
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetRecordingsRequest = GetRecordingsRequest

class GetRecordingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORDINGS_FIELD_NUMBER: builtins.int
    @property
    def recordings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.recording_v1.recording_pb2.Recording]: ...
    def __init__(
        self,
        *,
        recordings: collections.abc.Iterable[video.coordinator.recording_v1.recording_pb2.Recording] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["recordings", b"recordings"]) -> None: ...

global___GetRecordingsResponse = GetRecordingsResponse

class DeleteRecordingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteRecordingRequest = DeleteRecordingRequest

class DeleteRecordingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteRecordingResponse = DeleteRecordingResponse

class QueryCallTimelineEventsRequest(google.protobuf.message.Message):
    """A request message for the QueryCallTimelineEvents endpoint
    Specifies a subset of events to request
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SINCE_FIELD_NUMBER: builtins.int
    type: builtins.str
    """The call type."""
    id: builtins.str
    """The call id."""
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Limits event timespan of the response. Default: 10m, max: 30m"""
    @property
    def since(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """since which date to query events. Default: time of the first event of the call"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        since: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration", "since", b"since"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "id", b"id", "since", b"since", "type", b"type"]) -> None: ...

global___QueryCallTimelineEventsRequest = QueryCallTimelineEventsRequest

class QueryCallTimelineEventsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    NEXT_FIELD_NUMBER: builtins.int
    PARTICIPANT_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def start(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timeline inclusive start time"""
    @property
    def end(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """timeline inclusive end time"""
    @property
    def next(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """contains cursor to use to request the next page"""
    @property
    def participant_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.stat_v1.stat_pb2.CallParticipantTimeline]:
        """list of events for each participant from requested time period"""
    def __init__(
        self,
        *,
        start: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        next: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        participant_events: collections.abc.Iterable[video.coordinator.stat_v1.stat_pb2.CallParticipantTimeline] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end", b"end", "next", b"next", "start", b"start"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end", b"end", "next", b"next", "participant_events", b"participant_events", "start", b"start"]) -> None: ...

global___QueryCallTimelineEventsResponse = QueryCallTimelineEventsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import video.coordinator.call_v1.call_pb2
import video.coordinator.member_v1.member_pb2
import video.coordinator.recording_v1.recording_pb2
import video.coordinator.user_v1.user_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ExportUserEnvelope(google.protobuf.message.Message):
    """CallsEnvelope contains list of members and all related information to them
    Only used in response types that return list of members
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class MembersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> video.coordinator.member_v1.member_pb2.Member: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: video.coordinator.member_v1.member_pb2.Member | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USER_FIELD_NUMBER: builtins.int
    CALLS_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    RECORDINGS_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> video.coordinator.user_v1.user_pb2.User: ...
    @property
    def calls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.call_v1.call_pb2.Call]: ...
    @property
    def members(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, video.coordinator.member_v1.member_pb2.Member]:
        """Map of members indexed by Call.call_cid"""
    @property
    def recordings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.coordinator.recording_v1.recording_pb2.Recording]: ...
    def __init__(
        self,
        *,
        user: video.coordinator.user_v1.user_pb2.User | None = ...,
        calls: collections.abc.Iterable[video.coordinator.call_v1.call_pb2.Call] | None = ...,
        members: collections.abc.Mapping[builtins.str, video.coordinator.member_v1.member_pb2.Member] | None = ...,
        recordings: collections.abc.Iterable[video.coordinator.recording_v1.recording_pb2.Recording] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["calls", b"calls", "members", b"members", "recordings", b"recordings", "user", b"user"]) -> None: ...

global___ExportUserEnvelope = ExportUserEnvelope



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/event_v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2
from video.coordinator.call_v1 import call_pb2 as video_dot_coordinator_dot_call__v1_dot_call__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&video/coordinator/event_v1/event.proto\x12!stream.video.coordinator.event_v1\x1a\x17validate/validate.proto\x1a$video/coordinator/call_v1/call.proto\"\xa1\x01\n\x10RecordingStarted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xa1\x01\n\x10RecordingStopped\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\'\n\x0bUserUpdated\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xa1\x01\n\x10\x42roadcastStarted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x9f\x01\n\x0e\x42roadcastEnded\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xb4\x01\n\x12\x43\x61llMembersCreated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07ringing\x18\x03 \x01(\x08\"\xa3\x01\n\x12\x43\x61llMembersUpdated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xa3\x01\n\x12\x43\x61llMembersDeleted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xad\x01\n\x0b\x43\x61llCreated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07ringing\x18\x03 \x01(\x08\"\x9c\x01\n\x0b\x43\x61llUpdated\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x9a\x01\n\tCallEnded\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x9c\x01\n\x0b\x43\x61llDeleted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xbe\x01\n\x0c\x43\x61llAccepted\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xbe\x01\n\x0c\x43\x61llRejected\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xbf\x01\n\rCallCancelled\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xe6\x01\n\nCallCustom\x12>\n\x04\x63\x61ll\x18\x01 \x01(\x0b\x32&.stream.video.coordinator.call_v1.CallB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12M\n\x0c\x63\x61ll_details\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallDetailsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1f\n\x0esender_user_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04type\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tdata_json\x18\x05 \x01(\x0c\x42\x33\x42\x07\x45ventV1P\x01Z\x08\x65vent_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.event_v1.event_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\007EventV1P\001Z\010event_v1\252\002\033Stream.Video.v1.Coordinator'
  _RECORDINGSTARTED.fields_by_name['call']._options = None
  _RECORDINGSTARTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RECORDINGSTARTED.fields_by_name['call_details']._options = None
  _RECORDINGSTARTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RECORDINGSTOPPED.fields_by_name['call']._options = None
  _RECORDINGSTOPPED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RECORDINGSTOPPED.fields_by_name['call_details']._options = None
  _RECORDINGSTOPPED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _USERUPDATED.fields_by_name['user_id']._options = None
  _USERUPDATED.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _BROADCASTSTARTED.fields_by_name['call']._options = None
  _BROADCASTSTARTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BROADCASTSTARTED.fields_by_name['call_details']._options = None
  _BROADCASTSTARTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BROADCASTENDED.fields_by_name['call']._options = None
  _BROADCASTENDED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BROADCASTENDED.fields_by_name['call_details']._options = None
  _BROADCASTENDED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSCREATED.fields_by_name['call']._options = None
  _CALLMEMBERSCREATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSCREATED.fields_by_name['call_details']._options = None
  _CALLMEMBERSCREATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSUPDATED.fields_by_name['call']._options = None
  _CALLMEMBERSUPDATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSUPDATED.fields_by_name['call_details']._options = None
  _CALLMEMBERSUPDATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSDELETED.fields_by_name['call']._options = None
  _CALLMEMBERSDELETED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLMEMBERSDELETED.fields_by_name['call_details']._options = None
  _CALLMEMBERSDELETED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCREATED.fields_by_name['call']._options = None
  _CALLCREATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCREATED.fields_by_name['call_details']._options = None
  _CALLCREATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLUPDATED.fields_by_name['call']._options = None
  _CALLUPDATED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLUPDATED.fields_by_name['call_details']._options = None
  _CALLUPDATED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLENDED.fields_by_name['call']._options = None
  _CALLENDED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLENDED.fields_by_name['call_details']._options = None
  _CALLENDED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLDELETED.fields_by_name['call']._options = None
  _CALLDELETED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLDELETED.fields_by_name['call_details']._options = None
  _CALLDELETED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLACCEPTED.fields_by_name['call']._options = None
  _CALLACCEPTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLACCEPTED.fields_by_name['call_details']._options = None
  _CALLACCEPTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLACCEPTED.fields_by_name['sender_user_id']._options = None
  _CALLACCEPTED.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLREJECTED.fields_by_name['call']._options = None
  _CALLREJECTED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLREJECTED.fields_by_name['call_details']._options = None
  _CALLREJECTED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLREJECTED.fields_by_name['sender_user_id']._options = None
  _CALLREJECTED.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLCANCELLED.fields_by_name['call']._options = None
  _CALLCANCELLED.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCANCELLED.fields_by_name['call_details']._options = None
  _CALLCANCELLED.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCANCELLED.fields_by_name['sender_user_id']._options = None
  _CALLCANCELLED.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLCUSTOM.fields_by_name['call']._options = None
  _CALLCUSTOM.fields_by_name['call']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCUSTOM.fields_by_name['call_details']._options = None
  _CALLCUSTOM.fields_by_name['call_details']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CALLCUSTOM.fields_by_name['sender_user_id']._options = None
  _CALLCUSTOM.fields_by_name['sender_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLCUSTOM.fields_by_name['type']._options = None
  _CALLCUSTOM.fields_by_name['type']._serialized_options = b'\372B\004r\002\020\001'
  _RECORDINGSTARTED._serialized_start=141
  _RECORDINGSTARTED._serialized_end=302
  _RECORDINGSTOPPED._serialized_start=305
  _RECORDINGSTOPPED._serialized_end=466
  _USERUPDATED._serialized_start=468
  _USERUPDATED._serialized_end=507
  _BROADCASTSTARTED._serialized_start=510
  _BROADCASTSTARTED._serialized_end=671
  _BROADCASTENDED._serialized_start=674
  _BROADCASTENDED._serialized_end=833
  _CALLMEMBERSCREATED._serialized_start=836
  _CALLMEMBERSCREATED._serialized_end=1016
  _CALLMEMBERSUPDATED._serialized_start=1019
  _CALLMEMBERSUPDATED._serialized_end=1182
  _CALLMEMBERSDELETED._serialized_start=1185
  _CALLMEMBERSDELETED._serialized_end=1348
  _CALLCREATED._serialized_start=1351
  _CALLCREATED._serialized_end=1524
  _CALLUPDATED._serialized_start=1527
  _CALLUPDATED._serialized_end=1683
  _CALLENDED._serialized_start=1686
  _CALLENDED._serialized_end=1840
  _CALLDELETED._serialized_start=1843
  _CALLDELETED._serialized_end=1999
  _CALLACCEPTED._serialized_start=2002
  _CALLACCEPTED._serialized_end=2192
  _CALLREJECTED._serialized_start=2195
  _CALLREJECTED._serialized_end=2385
  _CALLCANCELLED._serialized_start=2388
  _CALLCANCELLED._serialized_end=2579
  _CALLCUSTOM._serialized_start=2582
  _CALLCUSTOM._serialized_end=2812
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import video.sfu.models.models_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class KickUserRequest(google.protobuf.message.Message):
    """A request message for KickUser endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PK_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    CALL_IDS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    NOT_BEFORE_FIELD_NUMBER: builtins.int
    app_pk: builtins.int
    """App PK"""
    user_id: builtins.str
    """An ID of the user to disconnect"""
    @property
    def call_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Call IDs to which this request applies.
        If empty, should be treated as "all calls"
        """
    message: builtins.str
    """A message to display to a user when its disconnected"""
    @property
    def not_before(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Optional. A timestamp which tells SFU to deny all tokens issued before this date"""
    def __init__(
        self,
        *,
        app_pk: builtins.int = ...,
        user_id: builtins.str = ...,
        call_ids: collections.abc.Iterable[builtins.str] | None = ...,
        message: builtins.str = ...,
        not_before: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["not_before", b"not_before"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_pk", b"app_pk", "call_ids", b"call_ids", "message", b"message", "not_before", b"not_before", "user_id", b"user_id"]) -> None: ...

global___KickUserRequest = KickUserRequest

class KickUserResponse(google.protobuf.message.Message):
    """A response message for KickUser endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KickUserResponse = KickUserResponse

class InvalidateTokenRequest(google.protobuf.message.Message):
    """A request message for InvaludateUserToken endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PK_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    CALL_IDS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    NOT_BEFORE_FIELD_NUMBER: builtins.int
    app_pk: builtins.int
    """App PK"""
    user_id: builtins.str
    """An ID of the user to invalidate tokens for"""
    @property
    def call_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Call IDs to which this request applies.
        If empty, should be treated as "all calls"
        """
    message: builtins.str
    """A message to display to a user in the event of disconnect"""
    @property
    def not_before(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """A cut-off date for all the tokens"""
    def __init__(
        self,
        *,
        app_pk: builtins.int = ...,
        user_id: builtins.str = ...,
        call_ids: collections.abc.Iterable[builtins.str] | None = ...,
        message: builtins.str = ...,
        not_before: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["not_before", b"not_before"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_pk", b"app_pk", "call_ids", b"call_ids", "message", b"message", "not_before", b"not_before", "user_id", b"user_id"]) -> None: ...

global___InvalidateTokenRequest = InvalidateTokenRequest

class InvalidateTokenResponse(google.protobuf.message.Message):
    """A response message for InvaludateUserToken endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InvalidateTokenResponse = InvalidateTokenResponse

class MuteParticipantsRequest(google.protobuf.message.Message):
    """A request message for MuteParticipants endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PK_FIELD_NUMBER: builtins.int
    PARTICIPANTS_FIELD_NUMBER: builtins.int
    app_pk: builtins.int
    """App PK"""
    @property
    def participants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[video.sfu.models.models_pb2.Participant]:
        """List of part"""
    def __init__(
        self,
        *,
        app_pk: builtins.int = ...,
        participants: collections.abc.Iterable[video.sfu.models.models_pb2.Participant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_pk", b"app_pk", "participants", b"participants"]) -> None: ...

global___MuteParticipantsRequest = MuteParticipantsRequest

class MuteParticipantInput(google.protobuf.message.Message):
    """A message that tells which participant to mute"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    MUTE_AUDIO_FIELD_NUMBER: builtins.int
    MUTE_VIDEO_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """User ID to mute"""
    session_id: builtins.str
    """Session ID to mute
    If empty, all sessions of provided user ID should be muted
    """
    mute_audio: builtins.bool
    """Whether to mute video"""
    mute_video: builtins.bool
    """Whether to mute audio"""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        session_id: builtins.str | None = ...,
        mute_audio: builtins.bool | None = ...,
        mute_video: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_mute_audio", b"_mute_audio", "_mute_video", b"_mute_video", "_session_id", b"_session_id", "mute_audio", b"mute_audio", "mute_video", b"mute_video", "session_id", b"session_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_mute_audio", b"_mute_audio", "_mute_video", b"_mute_video", "_session_id", b"_session_id", "mute_audio", b"mute_audio", "mute_video", b"mute_video", "session_id", b"session_id", "user_id", b"user_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_mute_audio", b"_mute_audio"]) -> typing_extensions.Literal["mute_audio"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_mute_video", b"_mute_video"]) -> typing_extensions.Literal["mute_video"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_session_id", b"_session_id"]) -> typing_extensions.Literal["session_id"] | None: ...

global___MuteParticipantInput = MuteParticipantInput

class MuteParticipantsResponse(google.protobuf.message.Message):
    """A response message for MuteParticipants endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MuteParticipantsResponse = MuteParticipantsResponse

class GetCallRequest(google.protobuf.message.Message):
    """A request message for GetCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    WITH_STATE_FIELD_NUMBER: builtins.int
    app_pk: builtins.int
    """App PK"""
    id: builtins.str
    """A call ID"""
    with_state: builtins.bool
    """Whether to include state information in the response"""
    def __init__(
        self,
        *,
        app_pk: builtins.int = ...,
        id: builtins.str = ...,
        with_state: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_pk", b"app_pk", "id", b"id", "with_state", b"with_state"]) -> None: ...

global___GetCallRequest = GetCallRequest

class GetCallResponse(google.protobuf.message.Message):
    """A response message for GetCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.sfu.models.models_pb2.Call:
        """Call model"""
    @property
    def state(self) -> video.sfu.models.models_pb2.CallState:
        """Call state"""
    def __init__(
        self,
        *,
        call: video.sfu.models.models_pb2.Call | None = ...,
        state: video.sfu.models.models_pb2.CallState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call", "state", b"state"]) -> None: ...

global___GetCallResponse = GetCallResponse

class CreateCallRequest(google.protobuf.message.Message):
    """A request message for CreateCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CASCADING_SFUS_HOSTNAMES_FIELD_NUMBER: builtins.int
    GOSSIP_RPC_AUTH_TOKEN_FIELD_NUMBER: builtins.int
    app_pk: builtins.int
    """App PK"""
    id: builtins.str
    """Call ID"""
    @property
    def cascading_sfus_hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of SFUs that are used for this call"""
    gossip_rpc_auth_token: builtins.str
    """The token the SFU can use to participate in the gossip protocol"""
    def __init__(
        self,
        *,
        app_pk: builtins.int = ...,
        id: builtins.str = ...,
        cascading_sfus_hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        gossip_rpc_auth_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_pk", b"app_pk", "cascading_sfus_hostnames", b"cascading_sfus_hostnames", "gossip_rpc_auth_token", b"gossip_rpc_auth_token", "id", b"id"]) -> None: ...

global___CreateCallRequest = CreateCallRequest

class CreateCallResponse(google.protobuf.message.Message):
    """A response message for CreateCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.sfu.models.models_pb2.Call:
        """A model of created call"""
    def __init__(
        self,
        *,
        call: video.sfu.models.models_pb2.Call | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call"]) -> None: ...

global___CreateCallResponse = CreateCallResponse

class EndCallRequest(google.protobuf.message.Message):
    """A request message for EndCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_PK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    app_pk: builtins.int
    """App PK"""
    id: builtins.str
    """Call ID"""
    message: builtins.str
    """A message to display to disconnected participants"""
    def __init__(
        self,
        *,
        app_pk: builtins.int = ...,
        id: builtins.str = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_pk", b"app_pk", "id", b"id", "message", b"message"]) -> None: ...

global___EndCallRequest = EndCallRequest

class EndCallResponse(google.protobuf.message.Message):
    """A response message for EndCall endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CALL_FIELD_NUMBER: builtins.int
    @property
    def call(self) -> video.sfu.models.models_pb2.Call:
        """A model of a call
        TODO: return some call stats?
        """
    def __init__(
        self,
        *,
        call: video.sfu.models.models_pb2.Call | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["call", b"call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call", b"call"]) -> None: ...

global___EndCallResponse = EndCallResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permissions/permissions_v1_rpc/permissions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0permissions/permissions_v1_rpc/permissions.proto\x12%stream.permissions.permissions_v1_rpc\x1a\x1fgoogle/protobuf/timestamp.proto\"!\n\x11\x43reateRoleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"O\n\x12\x43reateRoleResponse\x12\x39\n\x04role\x18\x01 \x01(\x0b\x32+.stream.permissions.permissions_v1_rpc.Role\"!\n\x11\x44\x65leteRoleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteRoleResponse\"\x13\n\x11QueryRolesRequest\"P\n\x12QueryRolesResponse\x12:\n\x05roles\x18\x01 \x03(\x0b\x32+.stream.permissions.permissions_v1_rpc.Role\"\x15\n\x13QueryActionsRequest\"V\n\x14QueryActionsResponse\x12>\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32-.stream.permissions.permissions_v1_rpc.Action\"\x19\n\x17QueryPermissionsRequest\"b\n\x18QueryPermissionsResponse\x12\x46\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x31.stream.permissions.permissions_v1_rpc.Permission\"\xdb\x01\n\x12UpdateScopeRequest\x12\x10\n\x08scope_id\x18\x01 \x01(\t\x12U\n\x06grants\x18\x02 \x03(\x0b\x32\x45.stream.permissions.permissions_v1_rpc.UpdateScopeRequest.GrantsEntry\x1a\\\n\x0bGrantsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.stream.permissions.permissions_v1_rpc.Grants:\x02\x38\x01\"4\n\x11ResetScopeRequest\x12\x10\n\x08scope_id\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"Q\n\x12ResetScopeResponse\x12;\n\x05scope\x18\x01 \x01(\x0b\x32,.stream.permissions.permissions_v1_rpc.Scope\"R\n\x13UpdateScopeResponse\x12;\n\x05scope\x18\x01 \x01(\x0b\x32,.stream.permissions.permissions_v1_rpc.Scope\"\x14\n\x12QueryScopesRequest\"\xca\x01\n\x13QueryScopesResponse\x12V\n\x06scopes\x18\x01 \x03(\x0b\x32\x46.stream.permissions.permissions_v1_rpc.QueryScopesResponse.ScopesEntry\x1a[\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.stream.permissions.permissions_v1_rpc.Scope:\x02\x38\x01\"9\n\x06\x41\x63tion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"\xb7\x01\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12H\n\x06simple\x18\x05 \x01(\x0b\x32\x36.stream.permissions.permissions_v1_rpc.SimpleConditionH\x00\x12\x13\n\tcustom_mq\x18\x06 \x01(\x0cH\x00\x42\x0b\n\tcondition\"3\n\x0fSimpleCondition\x12\r\n\x05owner\x18\x01 \x01(\x08\x12\x11\n\tsame_team\x18\x02 \x01(\x08\"D\n\x04Role\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd0\x01\n\x05Scope\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12H\n\x06grants\x18\x03 \x03(\x0b\x32\x38.stream.permissions.permissions_v1_rpc.Scope.GrantsEntry\x1a\\\n\x0bGrantsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.stream.permissions.permissions_v1_rpc.Grants:\x02\x38\x01\"+\n\x06Grants\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x13\n\x0bpermissions\x18\x02 \x03(\t2\xce\x08\n\x0ePermissionsRPC\x12\x81\x01\n\nCreateRole\x12\x38.stream.permissions.permissions_v1_rpc.CreateRoleRequest\x1a\x39.stream.permissions.permissions_v1_rpc.CreateRoleResponse\x12\x81\x01\n\nDeleteRole\x12\x38.stream.permissions.permissions_v1_rpc.DeleteRoleRequest\x1a\x39.stream.permissions.permissions_v1_rpc.DeleteRoleResponse\x12\x81\x01\n\nQueryRoles\x12\x38.stream.permissions.permissions_v1_rpc.QueryRolesRequest\x1a\x39.stream.permissions.permissions_v1_rpc.QueryRolesResponse\x12\x84\x01\n\x0bQueryScopes\x12\x39.stream.permissions.permissions_v1_rpc.QueryScopesRequest\x1a:.stream.permissions.permissions_v1_rpc.QueryScopesResponse\x12\x84\x01\n\x0bUpdateScope\x12\x39.stream.permissions.permissions_v1_rpc.UpdateScopeRequest\x1a:.stream.permissions.permissions_v1_rpc.UpdateScopeResponse\x12\x81\x01\n\nResetScope\x12\x38.stream.permissions.permissions_v1_rpc.ResetScopeRequest\x1a\x39.stream.permissions.permissions_v1_rpc.ResetScopeResponse\x12\x87\x01\n\x0cQueryActions\x12:.stream.permissions.permissions_v1_rpc.QueryActionsRequest\x1a;.stream.permissions.permissions_v1_rpc.QueryActionsResponse\x12\x93\x01\n\x10QueryPermissions\x12>.stream.permissions.permissions_v1_rpc.QueryPermissionsRequest\x1a?.stream.permissions.permissions_v1_rpc.QueryPermissionsResponseB7B\rPermissionsV1P\x01Z\x12permissions_v1_rpc\xaa\x02\x0fStream.Video.v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'permissions.permissions_v1_rpc.permissions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\rPermissionsV1P\001Z\022permissions_v1_rpc\252\002\017Stream.Video.v1'
  _UPDATESCOPEREQUEST_GRANTSENTRY._options = None
  _UPDATESCOPEREQUEST_GRANTSENTRY._serialized_options = b'8\001'
  _QUERYSCOPESRESPONSE_SCOPESENTRY._options = None
  _QUERYSCOPESRESPONSE_SCOPESENTRY._serialized_options = b'8\001'
  _SCOPE_GRANTSENTRY._options = None
  _SCOPE_GRANTSENTRY._serialized_options = b'8\001'
  _CREATEROLEREQUEST._serialized_start=124
  _CREATEROLEREQUEST._serialized_end=157
  _CREATEROLERESPONSE._serialized_start=159
  _CREATEROLERESPONSE._serialized_end=238
  _DELETEROLEREQUEST._serialized_start=240
  _DELETEROLEREQUEST._serialized_end=273
  _DELETEROLERESPONSE._serialized_start=275
  _DELETEROLERESPONSE._serialized_end=295
  _QUERYROLESREQUEST._serialized_start=297
  _QUERYROLESREQUEST._serialized_end=316
  _QUERYROLESRESPONSE._serialized_start=318
  _QUERYROLESRESPONSE._serialized_end=398
  _QUERYACTIONSREQUEST._serialized_start=400
  _QUERYACTIONSREQUEST._serialized_end=421
  _QUERYACTIONSRESPONSE._serialized_start=423
  _QUERYACTIONSRESPONSE._serialized_end=509
  _QUERYPERMISSIONSREQUEST._serialized_start=511
  _QUERYPERMISSIONSREQUEST._serialized_end=536
  _QUERYPERMISSIONSRESPONSE._serialized_start=538
  _QUERYPERMISSIONSRESPONSE._serialized_end=636
  _UPDATESCOPEREQUEST._serialized_start=639
  _UPDATESCOPEREQUEST._serialized_end=858
  _UPDATESCOPEREQUEST_GRANTSENTRY._serialized_start=766
  _UPDATESCOPEREQUEST_GRANTSENTRY._serialized_end=858
  _RESETSCOPEREQUEST._serialized_start=860
  _RESETSCOPEREQUEST._serialized_end=912
  _RESETSCOPERESPONSE._serialized_start=914
  _RESETSCOPERESPONSE._serialized_end=995
  _UPDATESCOPERESPONSE._serialized_start=997
  _UPDATESCOPERESPONSE._serialized_end=1079
  _QUERYSCOPESREQUEST._serialized_start=1081
  _QUERYSCOPESREQUEST._serialized_end=1101
  _QUERYSCOPESRESPONSE._serialized_start=1104
  _QUERYSCOPESRESPONSE._serialized_end=1306
  _QUERYSCOPESRESPONSE_SCOPESENTRY._serialized_start=1215
  _QUERYSCOPESRESPONSE_SCOPESENTRY._serialized_end=1306
  _ACTION._serialized_start=1308
  _ACTION._serialized_end=1365
  _PERMISSION._serialized_start=1368
  _PERMISSION._serialized_end=1551
  _SIMPLECONDITION._serialized_start=1553
  _SIMPLECONDITION._serialized_end=1604
  _ROLE._serialized_start=1606
  _ROLE._serialized_end=1674
  _SCOPE._serialized_start=1677
  _SCOPE._serialized_end=1885
  _SCOPE_GRANTSENTRY._serialized_start=766
  _SCOPE_GRANTSENTRY._serialized_end=858
  _GRANTS._serialized_start=1887
  _GRANTS._serialized_end=1930
  _PERMISSIONSRPC._serialized_start=1933
  _PERMISSIONSRPC._serialized_end=3035
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Codec:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CodecEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Codec.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CODEC_H264_UNSPECIFIED: _Codec.ValueType  # 0
    CODEC_VP8: _Codec.ValueType  # 1
    CODEC_VP9: _Codec.ValueType  # 2

class Codec(_Codec, metaclass=_CodecEnumTypeWrapper): ...

CODEC_H264_UNSPECIFIED: Codec.ValueType  # 0
CODEC_VP8: Codec.ValueType  # 1
CODEC_VP9: Codec.ValueType  # 2
global___Codec = Codec

class RTMPOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URLS_FIELD_NUMBER: builtins.int
    @property
    def urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["urls", b"urls"]) -> None: ...

global___RTMPOptions = RTMPOptions

class Broadcast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RTMP_FIELD_NUMBER: builtins.int
    HLS_URL_FIELD_NUMBER: builtins.int
    @property
    def rtmp(self) -> global___RTMPOptions: ...
    hls_url: builtins.str
    def __init__(
        self,
        *,
        rtmp: global___RTMPOptions | None = ...,
        hls_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rtmp", b"rtmp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hls_url", b"hls_url", "rtmp", b"rtmp"]) -> None: ...

global___Broadcast = Broadcast



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: video/coordinator/call_v1/call.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from video.coordinator.member_v1 import member_pb2 as video_dot_coordinator_dot_member__v1_dot_member__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$video/coordinator/call_v1/call.proto\x12 stream.video.coordinator.call_v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a(video/coordinator/member_v1/member.proto\"\xb8\x01\n\x08\x43\x61llType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x07options\x18\x02 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9e\x02\n\x04\x43\x61ll\x12\x15\n\x04type\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x02id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x08\x63\x61ll_cid\x18\x03 \x01(\t\x12#\n\x12\x63reated_by_user_id\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x63ustom_json\x18\x05 \x01(\x0c\x12>\n\x07options\x18\x06 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8f\x02\n\x0b\x43\x61llDetails\x12>\n\x07options\x18\x01 \x01(\x0b\x32-.stream.video.coordinator.call_v1.CallOptions\x12\x17\n\x0fmember_user_ids\x18\x02 \x03(\t\x12K\n\x07members\x18\x03 \x03(\x0b\x32:.stream.video.coordinator.call_v1.CallDetails.MembersEntry\x1aZ\n\x0cMembersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.stream.video.coordinator.member_v1.Member:\x02\x38\x01\"\xa1\x01\n\x0b\x43\x61llOptions\x12\x45\n\trecording\x18\x01 \x01(\x0b\x32\x32.stream.video.coordinator.call_v1.RecordingOptions\x12K\n\x0c\x62roadcasting\x18\x02 \x01(\x0b\x32\x35.stream.video.coordinator.call_v1.BroadcastingOptions\"4\n\x10RecordingOptions\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabled\"7\n\x13\x42roadcastingOptions\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabledB1B\x06\x43\x61llV1P\x01Z\x07\x63\x61ll_v1\xaa\x02\x1bStream.Video.v1.Coordinatorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'video.coordinator.call_v1.call_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\006CallV1P\001Z\007call_v1\252\002\033Stream.Video.v1.Coordinator'
  _CALL.fields_by_name['type']._options = None
  _CALL.fields_by_name['type']._serialized_options = b'\372B\004r\002\020\001'
  _CALL.fields_by_name['id']._options = None
  _CALL.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _CALL.fields_by_name['created_by_user_id']._options = None
  _CALL.fields_by_name['created_by_user_id']._serialized_options = b'\372B\004r\002\020\001'
  _CALLDETAILS_MEMBERSENTRY._options = None
  _CALLDETAILS_MEMBERSENTRY._serialized_options = b'8\001'
  _CALLTYPE._serialized_start=175
  _CALLTYPE._serialized_end=359
  _CALL._serialized_start=362
  _CALL._serialized_end=648
  _CALLDETAILS._serialized_start=651
  _CALLDETAILS._serialized_end=922
  _CALLDETAILS_MEMBERSENTRY._serialized_start=832
  _CALLDETAILS_MEMBERSENTRY._serialized_end=922
  _CALLOPTIONS._serialized_start=925
  _CALLOPTIONS._serialized_end=1086
  _RECORDINGOPTIONS._serialized_start=1088
  _RECORDINGOPTIONS._serialized_end=1140
  _BROADCASTINGOPTIONS._serialized_start=1142
  _BROADCASTINGOPTIONS._serialized_end=1197
# @@protoc_insertion_point(module_scope)
